@@ -15,16 +15,17 @@ Net::TacacsPlus - Tacacs+ library
 
 =head1 DESCRIPTION
 
-For now tacacs client authentication implemented. See L<Net::TacacsPlus::Client>.
+Tacacs+ client implemented by L<Net::TacacsPlus::Client>.
+Tacacs+ server (pap auth only) implemented by L<POE::Component::Server::TacacsPlus>.
 
 =cut
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use strict;
 use warnings;
 
-use Net::TacacsPlus::Client 1.05;
+use Net::TacacsPlus::Client 1.06;
 
 use Exporter;
 use 5.006;
@@ -54,11 +55,16 @@ sub tacacs_client {
 
 1;
 
+=head1 LINKS
+
+Net::TacacsPlus Trac page L<http://trac.cle.sk/Net-TacacsPlus/>
 
 =head1 AUTHOR
 
 Jozef Kutej - E<lt>jozef@kutej.netE<gt>
 
+Authorization and Accounting contributed by Rubio Vaughan E<lt>rubio@passim.netE<gt>
+
 =head1 SEE ALSO
 
 tac-rfc.1.78.txt
